/****************************************************************************
** Meta object code from reading C++ file 'xdgmenurules.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../libqtxdg-4.4.0/src/qtxdg/xdgmenurules.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xdgmenurules.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11XdgMenuRuleE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRule::qt_create_metaobjectdata<qt_meta_tag_ZN11XdgMenuRuleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRule"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRule, qt_meta_tag_ZN11XdgMenuRuleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRule::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11XdgMenuRuleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11XdgMenuRuleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11XdgMenuRuleE_t>.metaTypes,
    nullptr
} };

void XdgMenuRule::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRule *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRule::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRule::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11XdgMenuRuleE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XdgMenuRule::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13XdgMenuRuleOrE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRuleOr::qt_create_metaobjectdata<qt_meta_tag_ZN13XdgMenuRuleOrE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRuleOr"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRuleOr, qt_meta_tag_ZN13XdgMenuRuleOrE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRuleOr::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgMenuRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13XdgMenuRuleOrE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13XdgMenuRuleOrE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13XdgMenuRuleOrE_t>.metaTypes,
    nullptr
} };

void XdgMenuRuleOr::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRuleOr *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRuleOr::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleOr::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13XdgMenuRuleOrE_t>.strings))
        return static_cast<void*>(this);
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleOr::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14XdgMenuRuleAndE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRuleAnd::qt_create_metaobjectdata<qt_meta_tag_ZN14XdgMenuRuleAndE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRuleAnd"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRuleAnd, qt_meta_tag_ZN14XdgMenuRuleAndE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRuleAnd::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgMenuRuleOr::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleAndE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleAndE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14XdgMenuRuleAndE_t>.metaTypes,
    nullptr
} };

void XdgMenuRuleAnd::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRuleAnd *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRuleAnd::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleAnd::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleAndE_t>.strings))
        return static_cast<void*>(this);
    return XdgMenuRuleOr::qt_metacast(_clname);
}

int XdgMenuRuleAnd::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRuleOr::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14XdgMenuRuleNotE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRuleNot::qt_create_metaobjectdata<qt_meta_tag_ZN14XdgMenuRuleNotE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRuleNot"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRuleNot, qt_meta_tag_ZN14XdgMenuRuleNotE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRuleNot::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgMenuRuleOr::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleNotE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleNotE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14XdgMenuRuleNotE_t>.metaTypes,
    nullptr
} };

void XdgMenuRuleNot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRuleNot *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRuleNot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleNot::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleNotE_t>.strings))
        return static_cast<void*>(this);
    return XdgMenuRuleOr::qt_metacast(_clname);
}

int XdgMenuRuleNot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRuleOr::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19XdgMenuRuleFileNameE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRuleFileName::qt_create_metaobjectdata<qt_meta_tag_ZN19XdgMenuRuleFileNameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRuleFileName"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRuleFileName, qt_meta_tag_ZN19XdgMenuRuleFileNameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRuleFileName::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgMenuRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19XdgMenuRuleFileNameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19XdgMenuRuleFileNameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19XdgMenuRuleFileNameE_t>.metaTypes,
    nullptr
} };

void XdgMenuRuleFileName::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRuleFileName *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRuleFileName::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleFileName::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19XdgMenuRuleFileNameE_t>.strings))
        return static_cast<void*>(this);
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleFileName::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19XdgMenuRuleCategoryE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRuleCategory::qt_create_metaobjectdata<qt_meta_tag_ZN19XdgMenuRuleCategoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRuleCategory"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRuleCategory, qt_meta_tag_ZN19XdgMenuRuleCategoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRuleCategory::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgMenuRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19XdgMenuRuleCategoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19XdgMenuRuleCategoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19XdgMenuRuleCategoryE_t>.metaTypes,
    nullptr
} };

void XdgMenuRuleCategory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRuleCategory *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRuleCategory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleCategory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19XdgMenuRuleCategoryE_t>.strings))
        return static_cast<void*>(this);
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleCategory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14XdgMenuRuleAllE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRuleAll::qt_create_metaobjectdata<qt_meta_tag_ZN14XdgMenuRuleAllE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRuleAll"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRuleAll, qt_meta_tag_ZN14XdgMenuRuleAllE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRuleAll::staticMetaObject = { {
    QMetaObject::SuperData::link<XdgMenuRule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleAllE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleAllE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14XdgMenuRuleAllE_t>.metaTypes,
    nullptr
} };

void XdgMenuRuleAll::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRuleAll *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRuleAll::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRuleAll::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14XdgMenuRuleAllE_t>.strings))
        return static_cast<void*>(this);
    return XdgMenuRule::qt_metacast(_clname);
}

int XdgMenuRuleAll::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XdgMenuRule::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN12XdgMenuRulesE_t {};
} // unnamed namespace

template <> constexpr inline auto XdgMenuRules::qt_create_metaobjectdata<qt_meta_tag_ZN12XdgMenuRulesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "XdgMenuRules"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XdgMenuRules, qt_meta_tag_ZN12XdgMenuRulesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject XdgMenuRules::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12XdgMenuRulesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12XdgMenuRulesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12XdgMenuRulesE_t>.metaTypes,
    nullptr
} };

void XdgMenuRules::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XdgMenuRules *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *XdgMenuRules::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XdgMenuRules::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12XdgMenuRulesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int XdgMenuRules::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
