// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_xdgaction.cpp"
#include "EWIEGA46WW/moc_xdgmenu.cpp"
#include "EWIEGA46WW/moc_xdgmenu_p.cpp"
#include "EWIEGA46WW/moc_xdgmenuapplinkprocessor.cpp"
#include "EWIEGA46WW/moc_xdgmenureader.cpp"
#include "EWIEGA46WW/moc_xdgmenurules.cpp"
#include "EWIEGA46WW/moc_xdgmenuwidget.cpp"
#include "EWIEGA46WW/moc_xdgmimeappsbackendinterface.cpp"
